@@ -42,7 +42,12 @@ class UsersMixin:
             return None, None
 
     def check_user_cookie(self, session_id, csrf_token):
-        pass
+        try:
+            headers = {"Cookie": "csrftoken={};sessionid={}".format(csrf_token, session_id)}
+            resp = self.http.get('user-profile', headers=headers, use_auth=False)
+        except (RequestError, ResponseError):
+            return None
+        return User.from_json(resp.json())
 
     def get_profile(self):
         try:
@@ -52,4 +57,3 @@ class UsersMixin:
 
         user = User.from_json(resp.json())
         return user
-
